# BookMaker

Ce projet est un ensemble de scripts et de fichier pour faciliter la
compilation de vos livres.

## Principe de compilation

La compilation du livre nécessite un fichier `makefile` à la racine de votre
projet qui définisse les macros suivantes :

* **bookmaker_SOURCE :** répertoire contenant les fichiers markdown à compiler,
* **bookmaker_COVER :** fichier contenant la couverture du livre en svg,
* **bookmaker_BUILD :** répertoire qui contiendra les fichiers compilés.

Vous pouve ensuite inclure le fichier `bookmaker.mk` et définir vos propres
cibles comme dans l'exemple suivant :

```makefile
bookmaker_SOURCE := ./text/
bookmaker_COVER  := ./cover/cover.svg
bookmaker_BUILD  := ./build

all      : bookmaker-all
clean    : bookmaker-clean
cleanall : bookmaker-cleanall
install  : bookmaker-install

include ./src/bookmaker.mk
```

Vous pouvez alors invoquer make qui se chargera de compiler les fichiers
nécessaires.

## Cible et fichier produits

Ce makefile a été construit pour produire les fichiers nécessaire à la
publication sur les plateformes suivantes :

* **lulu.com :** imprimeur à la demande, nécessite un fichier png pour la
  couverture et un fichier pdf pour le texte,
* **murder-party.com :** dépôt de scénario de soirées enquêtes, nécessite
  un pdf avec les couvertures intégrées,
* **Bibliothèque Nationale de France :** pour le dépôt légal, nécessite
  deux fichiers png pour la couverture.

Le texte produit correspond à un livre habituel avec les pages de titres
automatiquement générées. Il pré-suppose que votre ouvrage est imprimé
par `lulu.com` mais vous pouvez changer ces pages en éditant les fichiers
latex présents dans src (`copyright.tex` dans le cas présent).

## Dépendances

Pour utiliser ces scripts, vous aurez besoin des outils suivants :

* **make :** pour la compilation des sources et l'orchestration des outils,
* **pandoc :** pour la compilation du texte markdown en pdf (via latex), vous
  pouvez donc utiliser toutes les subtilités du markdown pour votre projet,
* **inkscape :** pour la convertion de la couverture svg en png, un fichier
  `cover.png` est fournis comme base,
* **convert :** pour convertir la couverture pdf en png,
* **pdftk :** pour concaténer la couverture et le texte en un seul fichier.

## Exemple

Le dossier `sample` contient un exemple de livre qu'il est possible de
compiler via les scripts de ce projet. Cet exemple ne contient que du
_lorem ipsum_ mais peut servir de base pour un projet.

## Licence d'utilisation

Ce projet est fournis sous licence _Creative Commons_ CC-NC-SA, disponible
à l'adresse suivante : `https://creativecommons.org/licenses/by-nc-sa/3.0/fr/`.
